@@ -14,7 +14,8 @@ def generate_barcode_b64image(barcode_number, text=None):
     buffer = io.BytesIO()
     generate(name="itf", code=barcode_number, output=buffer, text=text)
     base64_img = base64.b64encode(buffer.getvalue())
-    return base64_img.decode("utf-8")
+    base64_string = f"data:image/svg;base64,{base64_img.decode('utf-8')}"
+    return base64_string
 
 
 def parse_unicode_to_alphanumeric(string):
